@@ -8,7 +8,7 @@
 from typing import List, Optional, Union
 from pydantic import BaseModel
 from .literals import STATUS_STATE
-from .step import SwitchGuideStep, SwitchGuideStepComponent, SwitchGuideStepDependency, SwitchGuideStepOverrides
+from .step import SwitchGuideStep, SwitchGuideStepComponent, SwitchGuideStepDefinitionUiAssets, SwitchGuideStepDependency, SwitchGuideStepOverrides
 
 
 class SwitchGuideStatus(BaseModel):
@@ -25,10 +25,13 @@ class SwitchGuideSummaryStepEvents(BaseModel):
 
 
 class SwitchGuideSummaryStepConfigDefinition(BaseModel):
+    uiAssets: Optional[SwitchGuideStepDefinitionUiAssets]
     events: Optional[SwitchGuideSummaryStepEvents]
 
+
 class SwitchGuideSummaryStepConfig(BaseModel):
     component: Optional[SwitchGuideStepComponent]
+    uiAssets: Optional[SwitchGuideStepDefinitionUiAssets]
 
 class SwitchGuideDefinition(BaseModel):
     id: str = ''
