@@ -96,7 +96,28 @@ class SwitchGuideStepStatus(BaseModel):
 
 
 class SwitchGuideStepDefinitionUiAssets(BaseModel):
+    """Dynamically adjustable config to change UI look and feel. 
+    """
+    
+    """Step continue button text
+    """
     stepContinueButtonText: str = 'Get Started'
+    """Call To Action description to associate with the path.
+    """
+    progressCtaDescription: Optional[str] = None
+    """Call To Action path. Expected to be an internal route in the Platform App for now.
+    """
+    progressCtaPath: Optional[str] = None
+    """Call To Action text. By default it will be "Click here".
+    """
+    progressCtaText: Optional[str] = 'Click here'
+    """Text contained in the banner.
+    """
+    stepBannerText: Optional[str] = None
+    """Type of the banner. By default it will be of Type 'Note'.
+    In the future it could also be warnings and errors.
+    """
+    stepBannerType: Optional[str] = None
 
 
 class SwitchGuideStepDefinition(BaseModel):
